# Monte Carlo Module

The monte_carlo module contains Monte Carlo sampling and resampling functions.

::: bayesian_filters.monte_carlo
    options:
      show_root_heading: true
      show_source: false
      members: true
